# Its4landPublicApi.ContentItemsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getContentItem**](ContentItemsApi.md#getContentItem) | **GET** /contentitems/{contentitem_id} | Returns a single content from the object storage.
[**getContentItems**](ContentItemsApi.md#getContentItems) | **GET** /contentitems | Returns a list of contentitems
[**newContentItem**](ContentItemsApi.md#newContentItem) | **POST** /contentitems | Create a new content in the object storage


<a name="getContentItem"></a>
# **getContentItem**
> File getContentItem(contentitemId, opts, responseAsResult = *false*)

Returns a single content from the object storage.

Returns a single content from the object storage.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ContentItemsApi();

var contentitemId = "contentitemId_example"; // String | UID of the ContentItem

var opts = { 
  'envelope': "envelope_example" // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getContentItem(contentitemId, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contentitemId** | **String**| UID of the ContentItem | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 


### Return type

**File**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: multipart/form-data

<a name="getContentItems"></a>
# **getContentItems**
> [ContentItemEndpointType] getContentItems(opts, responseAsResult = *false*)

Returns a list of contentitems

Returns a list of contentitem metadata based on the filter criteria

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ContentItemsApi();

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'uid': ["uid_example"], // [String] | UID of a ContentItem
  'contentname': ["contentname_example"], // [String] | Name of File
  'contenttype': ["contenttype_example"], // [String] | mime/type of the content
  'contentdescription': "contentdescription_example", // String | Free text for description. Only plain text.
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getContentItems(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **uid** | [**[String]**](String.md)| UID of a ContentItem | [optional] 
 **contentname** | [**[String]**](String.md)| Name of File | [optional] 
 **contenttype** | [**[String]**](String.md)| mime/type of the content | [optional] 
 **contentdescription** | **String**| Free text for description. Only plain text. | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**[ContentItemEndpointType]**](ContentItemEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newContentItem"></a>
# **newContentItem**
> ContentItemEndpointType newContentItem(newcontent, opts, responseAsResult = *false*)

Create a new content in the object storage

Create a new content in the object storage

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ContentItemsApi();

var newcontent = "/path/to/file.txt"; // File | Content as multipart from-data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'description': "description_example", // String | Description of content (optional)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newContentItem(newcontent, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newcontent** | **File**| Content as multipart from-data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **description** | **String**| Description of content (optional) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ContentItemEndpointType**](ContentItemEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: application/json

